<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>DoctorCheck</title>
    <link rel="stylesheet" href="doctorcheck/static/css/style.css">
</head>
<body>
    {% block content %}
    {% endblock %}
    <script src="doctorcheck/static/js/script.js"></script>
</body>
</html>
